options nocenter validvarname=any;

*---Read in space-delimited ascii file;

data new_data;


infile 'mommarj06.dat' lrecl=44 missover DSD DLM=' ' print;
input
  R0000100
  R0214700
  R0214800
  R1395100
  R1395400
  R2720800
  R2720900
  R3915000
  R3915100
  R5053100
  R5053200
  R6430400
  R6430500
;
array nvarlist _numeric_;


*---Recode missing values to SAS custom system missing. See SAS
      documentation for use of MISSING option in procedures, e.g. PROC FREQ;

do over nvarlist;
  if nvarlist = -1 then nvarlist = .R;  /* Refused */
  if nvarlist = -2 then nvarlist = .D;  /* Dont know */
  if nvarlist = -3 then nvarlist = .I;  /* Invalid missing */
  if nvarlist = -4 then nvarlist = .V;  /* Valid missing */
  if nvarlist = -5 then nvarlist = .N;  /* Non-interview */
end;

  label R0000100 = "ID# (1-12686) 79";
  label R0214700 = "RACL/ETHNIC COHORT /SCRNR 79";
  label R0214800 = "SEX OF R 79";
  label R1395100 = "DRUG #TMS USE MARJ/HASH 84";
  label R1395400 = "DRUG AGE 1ST USED MARJ/HASH 84";
  label R2720800 = "DRUG #TMS USE MARJ/HASH LIFETIME 88";
  label R2720900 = "DRUG AGE 1ST USED MARJ/HASH 88";
  label R3915000 = "DRUG #TMS USE MARJ/HASH LIFE 92";
  label R3915100 = "DRUG AGE 1ST USED MARJ/HASH 92";
  label R5053100 = "TOT OCCASION R USE MARIJUANA 94";
  label R5053200 = "AGE 1ST TIME USED MARIJUANA 94";
  label R6430400 = "TOT OCCASION R USE MARIJUANA 1998";
  label R6430500 = "AGE 1ST TIME USED MARIJUANA 1998";

/*---------------------------------------------------------------------*
 *  Crosswalk for Reference number & Question name                     *
 *---------------------------------------------------------------------*
 * Uncomment and edit this RENAME statement to rename variables
 * for ease of use.  You may need to use  name literal strings
 * e.g.  'variable-name'n   to create valid SAS variable names, or 
 * alter variables similarly named across years.
 * This command does not guarentee uniqueness

 * See SAS documentation for use of name literals and use of the
 * VALIDVARNAME=ANY option.     
 *---------------------------------------------------------------------*/
  /* *start* */

* RENAME
  R0000100 = 'CASEID_1979'n
  R0214700 = '*Created_1979'n
  R0214800 = '*Created_1979'n
  R1395100 = 'Q5327_1984'n
  R1395400 = 'Q5332_1984'n
  R2720800 = 'QDS.1_1988'n
  R2720900 = 'QDS.2_1988'n
  R3915000 = 'Q7329_1992'n
  R3915100 = 'Q7331_1992'n
  R5053100 = 'DS-8_1994'n
  R5053200 = 'DS-9_1994'n
  R6430400 = 'DS-8_1998'n
  R6430500 = 'DS-9_1998'n
;
  /* *finish* */

run;

proc means data=new_data n mean min max;
run;


/*---------------------------------------------------------------------*
 *  FORMATTED TABULATIONS                                              *
 *---------------------------------------------------------------------*
 * You can uncomment and edit the PROC FORMAT and PROC FREQ statements 
 * provided below to obtain formatted tabulations. The tabulations 
 * should reflect codebook values.
 * 
 * Please edit the formats below reflect any renaming of the variables
 * you may have done in the first data step. 
 *---------------------------------------------------------------------*/

/*
proc format; 
*/

/* 
 *--- Tabulations using reference number variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
run;
*/

/*
*--- Tabulations using default named variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
run;
*/

