options nocenter validvarname=any;

*---Read in space-delimited ascii file;
*Karima note: Vars can be renamed in input statement as well without separate rename statement;
*Karima note: DSN name in data statement can be changed to reflect content;

data rni;


infile 'c:/workshops/summer_2009/working_with_data/rni_1980_2006.dat' lrecl=71 missover DSD DLM=' ' print;
input
  R0000100    /* caseid */
  R0406310    /* rni80  */
  R0618810    /* rni81  */
  R0898510    /* rni82  */
  R1144710    /* rni83  */
  R1519910    /* rni84  */
  R1890300    /* rni85  */
  R2257400    /* rni86  */
  R2444600    /* rni87  */
  R2870100    /* rni88  */
  R3073900    /* rni89  */
  R3400500    /* rni90  */
  R3655900    /* rni91  */
  R4006400    /* rni92  */
  R4417500    /* rni93  */
  R5080500    /* rni94  */
  R5165800    /* rni96  */
  R6478500    /* rni98  */
  R7006300    /* rni00  */
  R7703500    /* rni02  */
  R8495900    /* rni04  */
  T0987500    /* rni06  */
;
/* comment out array recoding missing values
array nvarlist _numeric_;


*---Recode missing values to SAS custom system missing. See SAS
      documentation for use of MISSING option in procedures, e.g. PROC FREQ;

do over nvarlist;
  if nvarlist = -1 then nvarlist = .R;  -- Refused --
  if nvarlist = -2 then nvarlist = .D;  -- Dont know --
  if nvarlist = -3 then nvarlist = .I;  -- Invalid missing --
  if nvarlist = -4 then nvarlist = .V;  -- Valid missing --
  if nvarlist = -5 then nvarlist = .N;  -- Non-interview --
end;
*/
  label R0000100 = "ID# (1-12686) 79";
  label R0406310 = "REASON FOR NONINT 80";
  label R0618810 = "REASON FOR NONINT 81";
  label R0898510 = "REASON FOR NONINT 82";
  label R1144710 = "REASON FOR NONINT 83";
  label R1519910 = "REASON FOR NONINT 84";
  label R1890300 = "REASON FOR NONINT 85";
  label R2257400 = "REASON FOR NONINT 86";
  label R2444600 = "REASON FOR NONINT 87";
  label R2870100 = "REASON FOR NONINT 88";
  label R3073900 = "REASON FOR NONINT 89";
  label R3400500 = "REASON FOR NONINT 90";
  label R3655900 = "REASON FOR NONINT 91";
  label R4006400 = "REASON FOR NONINT 92";
  label R4417500 = "REASONS FOR NON-INT 93";
  label R5080500 = "REASONS FOR NON-INT 94";
  label R5165800 = "REASONS FOR NON-INT 96";
  label R6478500 = "REASONS FOR NON-INT 1998";
  label R7006300 = "REASONS FOR NON-INT 2000";
  label R7703500 = "REASONS FOR NON-INT 2002";
  label R8495900 = "REASONS FOR NON-INT 2004";
  label T0987500 = "REASONS FOR NON-INT 2006";

/*---------------------------------------------------------------------*
 *  Crosswalk for Reference number & Question name                     *
 *---------------------------------------------------------------------*
 * Uncomment and edit this RENAME statement to rename variables
 * for ease of use.  You may need to use  name literal strings
 * e.g.  'variable-name'n   to create valid SAS variable names, or 
 * alter variables similarly named across years.
 * This command does not guarentee uniqueness

 * See SAS documentation for use of name literals and use of the
 * VALIDVARNAME=ANY option.     
 *---------------------------------------------------------------------*/
  /* *start* */
* uncomment rename statement to use;
* rename to names of your choosing - names generated by extract are commented out;
RENAME
  R0000100 = caseid     /* 'CASEID_1979'n    */
  R0406310 = rni1980    /* '*Created_1980'n  */
  R0618810 = rni1981    /* '*Created_1981'n  */
  R0898510 = rni1982    /* '*Created_1982'n  */
  R1144710 = rni1983    /* '*Created_1983'n  */
  R1519910 = rni1984    /* '*Created_1984'n  */
  R1890300 = rni1985    /* '*Created_1985'n  */
  R2257400 = rni1986    /* '*Created_1986'n  */
  R2444600 = rni1987    /* '*Created_1987'n  */
  R2870100 = rni1988    /* '*Created_1988'n  */
  R3073900 = rni1989    /* '*Created_1989'n  */
  R3400500 = rni1990    /* '*Created_1990'n  */
  R3655900 = rni1991    /* '*Created_1991'n  */
  R4006400 = rni1992    /* '*Created_1992'n  */
  R4417500 = rni1993    /* 'RNI_1993'n       */
  R5080500 = rni1994    /* 'RNI_1994'n       */
  R5165800 = rni1996    /* 'RNI_1996'n       */
  R6478500 = rni1998    /* 'RNI_1998'n       */
  R7006300 = rni2000    /* 'RNI_2000'n       */
  R7703500 = rni2002    /* 'RNI_2002'n       */
  R8495900 = rni2004    /* 'RNI_2004'n       */
  T0987500 = rni2006    /* 'RNI_2006'n       */
;
  /* *finish* */

run;

proc means data=rni n mean min max;
proc sort; by caseid;
run;


/*---------------------------------------------------------------------*
 *  FORMATTED TABULATIONS                                              *
 *---------------------------------------------------------------------*
 * You can uncomment and edit the PROC FORMAT and PROC FREQ statements 
 * provided below to obtain formatted tabulations. The tabulations 
 * should reflect codebook values.
 * 
 * Please edit the formats below reflect any renaming of the variables
 * you may have done in the first data step. 
 *---------------------------------------------------------------------*/

/*
proc format; 
*/

/* 
 *--- Tabulations using reference number variables;
proc freq data=rni;
tables _ALL_ /MISSING;
run;
*/

/*
*--- Tabulations using default named variables;
proc freq data=rni;
tables _ALL_ /MISSING;
run;
*/


* computes most recent interview year and number of years interviewed;
data compute1;
set rni;

* initialize rni for 1979 to -4 - there are no rnis for 1979;
rni1979=-4;

* array rnis from 2006 to 1979;
array rni (i) rni2006 rni2004 rni2002 rni2000 rni1998 rni1996 rni1994 rni1993 rni1992 rni1991 rni1990
              rni1989 rni1988 rni1987 rni1986 rni1985 rni1984 rni1983 rni1982 rni1981 rni1980 rni1979;

*compute a year of interview;
intyr2006=2006;
intyr2004=2004;
intyr2002=2002;
intyr2000=2000;
intyr1998=1998;
intyr1996=1996;
intyr1994=1994;
intyr1993=1993;
intyr1992=1992;
intyr1991=1991;
intyr1990=1990;
intyr1989=1989;
intyr1988=1988;
intyr1987=1987;
intyr1986=1986;
intyr1985=1985;
intyr1984=1984;
intyr1983=1983;
intyr1982=1982;
intyr1981=1981;
intyr1980=1980;
intyr1979=1979;

* array interview years from 2006 to 1979;
array intyr (i) intyr2006 intyr2004 intyr2002 intyr2000 intyr1998 intyr1996 intyr1994 intyr1993 
                intyr1992 intyr1991 intyr1990 intyr1989 intyr1988 intyr1987 intyr1986 intyr1985 
                intyr1984 intyr1983 intyr1982 intyr1981 intyr1980 intyr1979;
              
* computes most recent interview year;
* computes number of years interviewed;
lintyear = -4;
yrs_int = 0;
do i = 1 to 22;
 if (rni = -4) then lintyear = intyr;
 if (lintyear > -4) then do;
  goto out1;
 end;
end; out1:


do i = 1 to 22;
 if (rni = -4) then yrs_int = yrs_int+1;
end;
run;

* create sample of every 200 cases;
data sample200;
set compute1;

if mod(_N_, 200) =0  then output sample200;

run;


data test1;
set sample200;

proc print; var caseid lintyear yrs_int rni2006 rni2004 rni2002 rni2000 rni1998 rni1996 rni1994 rni1993 rni1992 rni1991 
              rni1990 rni1989 rni1988 rni1987 rni1986 rni1985 rni1984 rni1983 rni1982 rni1981 rni1980 rni1979;
 
run;
